pub type Result<T> = Result<T, TeaQLToolError>;Expand description
A standard result type alias used throughout the TeaQL Tool ecosystem.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(TeaQLToolError),
}pub type Result<T> = Result<T, TeaQLToolError>;A standard result type alias used throughout the TeaQL Tool ecosystem.
pub enum Result<T> {
Ok(T),
Err(TeaQLToolError),
}